Access the HTTP client written in Rust.
Cargo features
Reqwest feature forwards
These features forwards reqwest features:
- http2 (enabled by default): Enables HTTP/2 support.
- native-tls: Enables TLS functionality provided by native-tls.
- native-tls-vendored: Enables the vendored feature of native-tls.
- native-tls-alpn: Enables the alpn feature of native-tls.
- rustls-tls (enabled by default): Enables TLS functionality provided by rustls. Equivalent to rustls-tls-webpki-roots.
- rustls-tls-manual-roots: Enables TLS functionality provided by rustls, without setting any root certificates. Roots have to be specified manually.
- rustls-tls-webpki-roots: Enables TLS functionality provided by rustls, while using root certificates from the webpki-roots crate.
- rustls-tls-native-roots: Enables TLS functionality provided by rustls, while using root certificates from the rustls-native-certs crate.
- blocking: Provides the blocking client API.
- charset (enabled by default): Improved support for decoding text.
- cookies (enabled by default): Provides cookie session support.
- gzip: Provides response body gzip decompression.
- brotli: Provides response body brotli decompression.
- zstd: Provides response body zstd decompression.
- deflate: Provides response body deflate decompression.
- json: Provides serialization and deserialization for JSON bodies.
- multipart: Provides functionality for multipart forms.
- stream: Adds support for futures::Stream.
- socks: Provides SOCKS5 proxy support.
- trust-dns: Enables a trust-dns/Hickory DNS async resolver instead of the default threadpool using getaddrinfo.
- macos-system-configuration (deprecated, use
system-proxyinstead): Use Windows and macOS system proxy settings automatically. - system-proxy (enabled by default): Use Windows and macOS system proxy settings automatically.
tauri-plugin-http features
- tracing: Adds request, response, and cookie-store diagnostics through
tracing. - unsafe-headers: Allows webview requests to send any headers.
- dangerous-settings: Allows dangerous client settings such as accepting invalid certificates or hostnames.
Re-exports
pub use reqwest;